@@ -2,19 +2,20 @@
 
 __author__ = """Andres Kepler"""
 __email__ = 'andres.kepler@fleetcomplete.com'
-__version__ = '0.1.13'
+__version__ = '0.1.14'
 
 import datetime
-
-from scapy.all import *
 import struct
 import logging
+import re
 import logstash
+from scapy.all import *
 from logstash_formatter import LogstashFormatterV1
 
 # configure logging
 logging.basicConfig(level=logging.INFO)
 
+
 def logsstash_logging(args):
     logsstash_host, logsstash_port = args.logstash.split(":")
     logsstash_logger = logging.getLogger()
@@ -23,6 +24,7 @@ def logsstash_logging(args):
                                                          version=1,
                                                          message_type="driver-parser"))
 
+
 def packet_summary(pkt):
     ip_src = None
     ip_dst = None
@@ -144,10 +146,9 @@ def parse_file(args):
             terminal_type = "VT10"
             serial = v_serial
         else:
-            terminal_type = "Unknown"
-            serial = "Unknown"
+            continue
 
-        if serial == "Unknown" or (len(serial) < 15 or len(serial) > 15):
+        if not re.match("\d{15}", serial):
             continue
 
         payload = DataOut(serial,
